==============
 REANA client
==============

.. image:: https://img.shields.io/travis/reanahub/reana-client.svg
   :target: https://travis-ci.org/reanahub/reana-client

.. image:: https://img.shields.io/coveralls/reanahub/reana-client.svg
   :target: https://coveralls.io/r/reanahub/reana-client

.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
   :target: https://reana-client.readthedocs.io/en/latest/?badge=latest

.. image:: https://badge.waffle.io/reanahub/reana.svg?label=Status%3A%20ready%20for%20work&title=Issues%20ready%20for%20work
   :target: https://waffle.io/reanahub/reana

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/reana.svg
   :target: https://github.com/reanahub/reana-client/blob/master/COPYING

About
-----

REANA-Client is a component of the `REANA <http://reanahub.io/>`_ reusable
analysis platform. It provides a command-line client that allows researcher to
communicate to REANA cloud instances to submit, run, and manage their reusable
analysis workflows.

Features
--------

- run research analysis workflows on compute clouds
- seed analysis workspace with input code and data
- list submitted analyses and enquire about their statuses
- download results of finished analysis workflows

Useful links
------------

- `documentation <https://reana-client.readthedocs.io/>`_
- `releases <https://github.com/reanahub/reana-client/releases>`_
- `known issues <https://github.com/reanahub/reana-client/issues>`_
- `source code <https://github.com/reanahub/reana-client>`_

For more information about the REANA reusable analysis platform, please see the
general `REANA documentation <http://reana.readthedocs.io/>`_.
